@@ -21,6 +21,5 @@ pip install .
 pip install -r tests/requirement_tests.txt
 
 CURRENT=$(pwd)
-
 cd ..
-nosetests -P ${CURRENT}/tests
+pytest ${CURRENT}/tests
