@@ -9,10 +9,11 @@
 #include <morphio/mut/morphology.h>
 #include <morphio/mut/section.h>
 #include <morphio/mut/writers.h>
-#include <morphio/shared_utils.tpp>
 #include <morphio/soma.h>
 #include <morphio/tools.h>
 
+#include "../shared_utils.hpp"
+
 namespace morphio {
 namespace mut {
 
@@ -110,7 +111,6 @@ std::shared_ptr<Section> Morphology::appendRootSection(const std::shared_ptr<Sec
     const std::shared_ptr<Section> section_copy(new Section(this, _counter, *section_));
     _register(section_copy);
     _rootSections.push_back(section_copy);
-
     const bool emptySection = section_copy->points().empty();
     if (emptySection)
         printError(Warning::APPENDING_EMPTY_SECTION,
@@ -154,16 +154,19 @@ Morphology::~Morphology() {
     }
 }
 
-static void eraseByValue(std::vector<std::shared_ptr<Section>>& vec,
-                         const std::shared_ptr<Section>& section) {
+void Morphology::eraseByValue(std::vector<std::shared_ptr<Section>>& vec,
+                              const std::shared_ptr<Section> section) {
+    if (section->_morphology == this) {
+        section->_morphology = nullptr;
+        section->_id = 0xffffffff;
+    }
     vec.erase(std::remove(vec.begin(), vec.end(), section), vec.end());
 }
 
-void Morphology::deleteSection(const std::shared_ptr<Section>& section_, bool recursive)
-
-{
+void Morphology::deleteSection(std::shared_ptr<Section> section_, bool recursive) {
     if (!section_)
         return;
+
     unsigned int id = section_->id();
 
     if (recursive) {
@@ -176,14 +179,17 @@ void Morphology::deleteSection(const std::shared_ptr<Section>& section_, bool re
             deleteSection(*it, false);
         }
     } else {
-        for (auto& child : section_->children()) {
-            // Re-link children to their "grand-parent"
-            _parent[child->id()] = _parent[id];
-            _children[_parent[id]].push_back(child);
-            if (section_->isRoot())
+        // Careful not to use a reference here or you will face reference invalidation problem
+        // with vector resize
+        for (auto child : section_->children()) {
+            if (section_->isRoot()) {
                 _rootSections.push_back(child);
+            } else {
+                // Re-link children to their "grand-parent"
+                _children[_parent[id]].push_back(child);
+                _parent[child->id()] = _parent[id];
+            }
         }
-
         eraseByValue(_rootSections, section_);
         eraseByValue(_children[_parent[id]], section_);
         _children.erase(id);
@@ -201,11 +207,11 @@ void _appendProperties(Property::PointLevel& to, const Property::PointLevel& fro
         _appendVector(to._perimeters, from._perimeters, offset);
 }
 
-void Morphology::sanitize() {
-    sanitize(morphio::readers::DebugInfo());
+void Morphology::removeUnifurcations() {
+    removeUnifurcations(morphio::readers::DebugInfo());
 }
 
-void Morphology::sanitize(const morphio::readers::DebugInfo& debugInfo) {
+void Morphology::removeUnifurcations(const morphio::readers::DebugInfo& debugInfo) {
     morphio::readers::ErrorMessages err(debugInfo._filename);
 
     auto it = depth_begin();
@@ -255,6 +261,23 @@ void Morphology::sanitize(const morphio::readers::DebugInfo& debugInfo) {
     }
 }
 
+void Morphology::_raiseIfUnifurcations() {
+    for (auto it = depth_begin(); it != depth_end(); ++it) {
+        std::shared_ptr<Section> section_ = *it;
+        if (section_->isRoot())
+            continue;
+
+        unsigned int parentId = section_->parent()->id();
+
+        auto parent = section_->parent();
+        bool isUnifurcation = parent->children().size() == 1;
+
+        if (isUnifurcation) {
+            throw WriterError(readers::ErrorMessages().ERROR_ONLY_CHILD_SWC_WRITER(parentId));
+        }
+    }
+}
+
 Property::Properties Morphology::buildReadOnly() const {
     using std::setw;
     int sectionIdOnDisk = 0;
@@ -345,10 +368,7 @@ void Morphology::write(const std::string& filename) {
 
     std::string extension;
 
-    morphio::mut::Morphology clean(*this);
-    clean.sanitize();
-
-    for (const auto& root : clean.rootSections()) {
+    for (const auto& root : rootSections()) {
         if (root->points().size() < 2)
             throw morphio::SectionBuilderError("Root sections must have at least 2 points");
     }
@@ -357,12 +377,13 @@ void Morphology::write(const std::string& filename) {
         extension += my_tolower(c);
 
     if (extension == ".h5")
-        writer::h5(clean, filename);
+        writer::h5(*this, filename);
     else if (extension == ".asc")
-        writer::asc(clean, filename);
-    else if (extension == ".swc")
-        writer::swc(clean, filename);
-    else
+        writer::asc(*this, filename);
+    else if (extension == ".swc") {
+        _raiseIfUnifurcations();
+        writer::swc(*this, filename);
+    } else
         throw UnknownFileType(_err.ERROR_WRONG_EXTENSION(filename));
 }
 
